==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/dms/CfnCertificateProps.java <==
package software.amazon.awscdk.services.dms;

/**
 * Properties for defining a `CfnCertificate`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.dms.*;
 * CfnCertificateProps cfnCertificateProps = CfnCertificateProps.builder()
 *         .certificateIdentifier("certificateIdentifier")
 *         .certificatePem("certificatePem")
 *         .certificateWallet("certificateWallet")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:10.446Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_dms.CfnCertificateProps")
@software.amazon.jsii.Jsii.Proxy(CfnCertificateProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCertificateProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * A customer-assigned name for the certificate.
     * <p>
     * Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificateIdentifier() {
        return null;
    }

    /**
     * The contents of a `.pem` file, which contains an X.509 certificate.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificatePem() {
        return null;
    }

    /**
     * The location of an imported Oracle Wallet certificate for use with SSL.
     * <p>
     * An example is: <code>filebase64("${path.root}/rds-ca-2019-root.sso")</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificateWallet() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCertificateProps> {
        java.lang.String certificateIdentifier;
        java.lang.String certificatePem;
        java.lang.String certificateWallet;

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificateIdentifier}
         * @param certificateIdentifier A customer-assigned name for the certificate.
         *                              Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificateIdentifier(java.lang.String certificateIdentifier) {
            this.certificateIdentifier = certificateIdentifier;
            return this;
        }

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificatePem}
         * @param certificatePem The contents of a `.pem` file, which contains an X.509 certificate.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificatePem(java.lang.String certificatePem) {
            this.certificatePem = certificatePem;
            return this;
        }

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificateWallet}
         * @param certificateWallet The location of an imported Oracle Wallet certificate for use with SSL.
         *                          An example is: <code>filebase64("${path.root}/rds-ca-2019-root.sso")</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificateWallet(java.lang.String certificateWallet) {
            this.certificateWallet = certificateWallet;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCertificateProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCertificateProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCertificateProps {
        private final java.lang.String certificateIdentifier;
        private final java.lang.String certificatePem;
        private final java.lang.String certificateWallet;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.certificateIdentifier = software.amazon.jsii.Kernel.get(this, "certificateIdentifier", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.certificatePem = software.amazon.jsii.Kernel.get(this, "certificatePem", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.certificateWallet = software.amazon.jsii.Kernel.get(this, "certificateWallet", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.certificateIdentifier = builder.certificateIdentifier;
            this.certificatePem = builder.certificatePem;
            this.certificateWallet = builder.certificateWallet;
        }

        @Override
        public final java.lang.String getCertificateIdentifier() {
            return this.certificateIdentifier;
        }

        @Override
        public final java.lang.String getCertificatePem() {
            return this.certificatePem;
        }

        @Override
        public final java.lang.String getCertificateWallet() {
            return this.certificateWallet;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCertificateIdentifier() != null) {
                data.set("certificateIdentifier", om.valueToTree(this.getCertificateIdentifier()));
            }
            if (this.getCertificatePem() != null) {
                data.set("certificatePem", om.valueToTree(this.getCertificatePem()));
            }
            if (this.getCertificateWallet() != null) {
                data.set("certificateWallet", om.valueToTree(this.getCertificateWallet()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_dms.CfnCertificateProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCertificateProps.Jsii$Proxy that = (CfnCertificateProps.Jsii$Proxy) o;

            if (this.certificateIdentifier != null ? !this.certificateIdentifier.equals(that.certificateIdentifier) : that.certificateIdentifier != null) return false;
            if (this.certificatePem != null ? !this.certificatePem.equals(that.certificatePem) : that.certificatePem != null) return false;
            return this.certificateWallet != null ? this.certificateWallet.equals(that.certificateWallet) : that.certificateWallet == null;
        }

        @Override
        public final int hashCode() {
            int result = this.certificateIdentifier != null ? this.certificateIdentifier.hashCode() : 0;
            result = 31 * result + (this.certificatePem != null ? this.certificatePem.hashCode() : 0);
            result = 31 * result + (this.certificateWallet != null ? this.certificateWallet.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/dms/CfnCertificateProps.java <==
package software.amazon.awscdk.services.dms;

/**
 * Properties for defining a <code>CfnCertificate</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.dms.*;
 * CfnCertificateProps cfnCertificateProps = CfnCertificateProps.builder()
 *         .certificateIdentifier("certificateIdentifier")
 *         .certificatePem("certificatePem")
 *         .certificateWallet("certificateWallet")
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:30.667Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_dms.CfnCertificateProps")
@software.amazon.jsii.Jsii.Proxy(CfnCertificateProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCertificateProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * A customer-assigned name for the certificate.
     * <p>
     * Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificateidentifier">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificateidentifier</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificateIdentifier() {
        return null;
    }

    /**
     * The contents of a <code>.pem</code> file, which contains an X.509 certificate.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificatepem">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificatepem</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificatePem() {
        return null;
    }

    /**
     * The location of an imported Oracle Wallet certificate for use with SSL.
     * <p>
     * An example is: <code>filebase64("${path.root}/rds-ca-2019-root.sso")</code>
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificatewallet">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dms-certificate.html#cfn-dms-certificate-certificatewallet</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCertificateWallet() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCertificateProps> {
        java.lang.String certificateIdentifier;
        java.lang.String certificatePem;
        java.lang.String certificateWallet;

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificateIdentifier}
         * @param certificateIdentifier A customer-assigned name for the certificate.
         *                              Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificateIdentifier(java.lang.String certificateIdentifier) {
            this.certificateIdentifier = certificateIdentifier;
            return this;
        }

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificatePem}
         * @param certificatePem The contents of a <code>.pem</code> file, which contains an X.509 certificate.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificatePem(java.lang.String certificatePem) {
            this.certificatePem = certificatePem;
            return this;
        }

        /**
         * Sets the value of {@link CfnCertificateProps#getCertificateWallet}
         * @param certificateWallet The location of an imported Oracle Wallet certificate for use with SSL.
         *                          An example is: <code>filebase64("${path.root}/rds-ca-2019-root.sso")</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder certificateWallet(java.lang.String certificateWallet) {
            this.certificateWallet = certificateWallet;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCertificateProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCertificateProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCertificateProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCertificateProps {
        private final java.lang.String certificateIdentifier;
        private final java.lang.String certificatePem;
        private final java.lang.String certificateWallet;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.certificateIdentifier = software.amazon.jsii.Kernel.get(this, "certificateIdentifier", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.certificatePem = software.amazon.jsii.Kernel.get(this, "certificatePem", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.certificateWallet = software.amazon.jsii.Kernel.get(this, "certificateWallet", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.certificateIdentifier = builder.certificateIdentifier;
            this.certificatePem = builder.certificatePem;
            this.certificateWallet = builder.certificateWallet;
        }

        @Override
        public final java.lang.String getCertificateIdentifier() {
            return this.certificateIdentifier;
        }

        @Override
        public final java.lang.String getCertificatePem() {
            return this.certificatePem;
        }

        @Override
        public final java.lang.String getCertificateWallet() {
            return this.certificateWallet;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCertificateIdentifier() != null) {
                data.set("certificateIdentifier", om.valueToTree(this.getCertificateIdentifier()));
            }
            if (this.getCertificatePem() != null) {
                data.set("certificatePem", om.valueToTree(this.getCertificatePem()));
            }
            if (this.getCertificateWallet() != null) {
                data.set("certificateWallet", om.valueToTree(this.getCertificateWallet()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_dms.CfnCertificateProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCertificateProps.Jsii$Proxy that = (CfnCertificateProps.Jsii$Proxy) o;

            if (this.certificateIdentifier != null ? !this.certificateIdentifier.equals(that.certificateIdentifier) : that.certificateIdentifier != null) return false;
            if (this.certificatePem != null ? !this.certificatePem.equals(that.certificatePem) : that.certificatePem != null) return false;
            return this.certificateWallet != null ? this.certificateWallet.equals(that.certificateWallet) : that.certificateWallet == null;
        }

        @Override
        public final int hashCode() {
            int result = this.certificateIdentifier != null ? this.certificateIdentifier.hashCode() : 0;
            result = 31 * result + (this.certificatePem != null ? this.certificatePem.hashCode() : 0);
            result = 31 * result + (this.certificateWallet != null ? this.certificateWallet.hashCode() : 0);
            return result;
        }
    }
}
